@@ -26,8 +26,9 @@ Usage::
     list_tasks_paginator: ListTasksPaginator = client.get_paginator("list_tasks")
     ```
 """
-from typing import Iterator, List
+from typing import Generic, Iterator, List, TypeVar
 
+from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .type_defs import (
@@ -50,24 +51,34 @@ __all__ = (
 )
 
 
+_ItemTypeDef = TypeVar("_ItemTypeDef")
+
+
+class _PageIterator(Generic[_ItemTypeDef], PageIterator):
+    def __iter__(self) -> Iterator[_ItemTypeDef]:
+        """
+        Proxy method to specify iterator item type.
+        """
+
+
 class ListAgentsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Paginator.ListAgents)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Paginator.ListAgents)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listagentspaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListAgentsResponseTypeDef]:
+    ) -> _PageIterator[ListAgentsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Paginator.ListAgents.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Paginator.ListAgents.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listagentspaginator)
         """
 
 
 class ListLocationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Paginator.ListLocations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Paginator.ListLocations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listlocationspaginator)
     """
 
@@ -76,46 +87,46 @@ class ListLocationsPaginator(Boto3Paginator):
         *,
         Filters: List["LocationFilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListLocationsResponseTypeDef]:
+    ) -> _PageIterator[ListLocationsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Paginator.ListLocations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Paginator.ListLocations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listlocationspaginator)
         """
 
 
 class ListTagsForResourcePaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtagsforresourcepaginator)
     """
 
     def paginate(
         self, *, ResourceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListTagsForResourceResponseTypeDef]:
+    ) -> _PageIterator[ListTagsForResourceResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Paginator.ListTagsForResource.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtagsforresourcepaginator)
         """
 
 
 class ListTaskExecutionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtaskexecutionspaginator)
     """
 
     def paginate(
         self, *, TaskArn: str = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListTaskExecutionsResponseTypeDef]:
+    ) -> _PageIterator[ListTaskExecutionsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Paginator.ListTaskExecutions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtaskexecutionspaginator)
         """
 
 
 class ListTasksPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Paginator.ListTasks)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Paginator.ListTasks)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtaskspaginator)
     """
 
@@ -124,8 +135,8 @@ class ListTasksPaginator(Boto3Paginator):
         *,
         Filters: List["TaskFilterTypeDef"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListTasksResponseTypeDef]:
+    ) -> _PageIterator[ListTasksResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.30/reference/services/datasync.html#DataSync.Paginator.ListTasks.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.37/reference/services/datasync.html#DataSync.Paginator.ListTasks.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/paginators.html#listtaskspaginator)
         """
